/*
 * FS2 Format
 * Run this program to re-format the file system to force
 * reloading the Forth image when there is no interpreter access to 'restore'
 *
 * 22Jun2003	Ken Staton
 */

#memmap xmem


// Edit BIOS\RABBITBIOS.C : XMEM_RESERVE_SIZE = 0x8000	// 32KB

#define FS2_USE_PROGRAM_FLASH	32 // KB

#define LX_2_USE			fs_get_flash_lx()

#define MY_LS_SHIFT		8	// Log(base 2) of the desired LS size.  Run the
									// FS2INFO sample program to check out
									// suitable values.  The LS (logical sector)
									// size is the internal buffer unit used
									// by the filesystem.

#define FS_API_TRACE			// printf to diag on serial port A for FS2 routines


#use "fs2.lib"


#define PR_SERIAL(string)\
      SerialPuts( string );\
      while (SerialwrFree() != OUTBUFSIZE) ;

/*****************************************************************************

 DEFINES to make it easier to change the serial port

 Change the definition of PORT in this file
 _AND_
 change the definition of PORT in the assembly source file

*****************************************************************************/

#define spA 1
#define spB 2
#define spC 3

#define PORT spA


// go ahead and define buffer sizes for all possible serial ports

#define AINBUFSIZE 15
#define BINBUFSIZE 15
#define CINBUFSIZE 15

#define OUTBUFSIZE 63

#define AOUTBUFSIZE 63
#define BOUTBUFSIZE 63
#define COUTBUFSIZE 63



#define BAUDRATE 19200


      
/*****************************************************************************

SERIAL wrapper routines

*****************************************************************************/

int SerialOpen(long br)
{
#if PORT==spA
  return(serAopen(br));  
#elif PORT==spB
  return(serBopen(br));
#elif PORT==spC
  return(serCopen(br));
#endif

}

int SerialPutc(char ch)
{
#if PORT==spA 
  return(serAputc(ch));
#elif PORT==spB
  return(serBputc(ch));
#elif PORT==spC
  return(serCputc(ch));
#endif

}

int SerialGetc()
{
#if PORT==spA 
  return(serAgetc());
#elif PORT==spB
  return(serBgetc());
#elif PORT==spC
  return(serCgetc());
#endif

}

int SerialPuts(char *str)
{
#if PORT==spA 
  return(serAputs(str));
#elif PORT==spB
  return(serBputs(str));
#elif PORT==spC
  return(serCputs(str));
#endif

}

int SerialwrFree()
{
#if PORT==spA 
  return(serAwrFree());
#elif PORT==spB
  return(serBwrFree());
#elif PORT==spC
  return(serCwrFree());
#endif
}

void SerialClose()
{
#if PORT==spA 
  serAclose();
#elif PORT==spB
  serBclose();
#elif PORT==spC
  serCclose();
#endif
}


            

int main()
{
	int rc;						// Return code from filesystem functions
   long baud;

   baud = BAUDRATE;
   SerialOpen(baud);									

   PR_SERIAL("\r\nStarting FS2 format\r\n");
   
	if (!LX_2_USE)
	  {
		printf("The specified device (LX# %d) does not exist.  Change LX_2_USE.\n",
			(int)LX_2_USE);
	   PR_SERIAL("\r\nLX device FAILED!\r\n");
   	SerialClose();				
		exit(1);
	  }
	else
		printf("Using device LX# %d...\n", (int)LX_2_USE);

	/* initialize the filesystem. */
	rc = fs_init(0,0);
	if (rc)
	  {
		printf("Could not initialize filesystem, error number %d\n", errno);
	   PR_SERIAL("\r\nFS2 init FAILED!\r\n");
   	SerialClose();	
		exit(2);
	  }

	/*
	 *  format the filesystem
	 *  Note that formatting must be done _after_ the call to fs_init().
	 */

	rc = lx_format(LX_2_USE, 0);
	if (rc)
	  {
		printf("Format failed, error code %d\n", errno);
	   PR_SERIAL("\r\nFormat FAILED!\r\n");
   	SerialClose();			
		exit(3);
	  }
	
	printf("Capacity of LX# %d is approximately %ld\n",
		(int)LX_2_USE, fs_get_lx_size(LX_2_USE, 0, 0));

	fs_set_lx(LX_2_USE, LX_2_USE);

   PR_SERIAL("\r\nFS2 formatted!\r\n");
   SerialClose();	

	for(;;) ;  // don't allow program to reset & re-run if success.
	return 0;
}
